@@ -12,8 +12,8 @@ class GitResource(object):
         self.session = session
         self.time_out = time_out
 
-    def update_code(self, user, key):
-        data = {"user": user, "key":key}
+    def update_code(self, user, key, target_version):
+        data = {"user": user, "key":key, "target_version": target_version}
         url_ = "http://{0}:{1}/git".format(self.host, self.port)
         result = rest_post_json_call(url_, self.session, json.dumps(data), self.time_out)
         return result["resource"]
